@@ -638,7 +638,7 @@ class AsyncClient(BaseClient):
         data = {"valuation_asset": valuation_asset}
         return await self._request_future_private_api("post", "contract_balance_valuation", data=data)
 
-    async def future_account_info(self, symbol):
+    async def future_account_info(self, symbol=None):
         """
         获取账户信息
         symbol	false	string	品种代码		支持大小写,"BTC","ETH"...如果缺省，默认返回所有品种
@@ -654,7 +654,7 @@ class AsyncClient(BaseClient):
             return Result(rst.code, rst.status, rst.msg, new_data)
         return rst
 
-    async def future_position_info(self, symbol):
+    async def future_position_info(self, symbol=None):
         """
         获取持仓信息
         symbol	false	string	品种代码		支持大小写,"BTC","ETH"...如果缺省，默认返回所有品种
@@ -1061,7 +1061,7 @@ class AsyncClient(BaseClient):
         data = {"valuation_asset": valuation_asset}
         return await self._request_coin_margined_private_api("post", "swap_balance_valuation", data=data)
 
-    async def coin_margined_account_info(self, contract_code):
+    async def coin_margined_account_info(self, contract_code=None):
         """
         获取账户信息
         contract_code	false	string	支持大小写, "BTC-USD"... ,如果缺省，默认返回所有合约
