@@ -28,8 +28,8 @@ class ReconnectingWebSocket:
     def __init__(self, public=True, proxy=None, api_key: Optional[str] = None, api_secret: Optional[str] = None,
                  api_passphrase: Optional[str] = None, simulated=False):
         self._public = public
-        self.ws: aiohttp.ClientWebSocketResponse = None
-        self._session: aiohttp.ClientSession = None
+        self.ws: Optional[aiohttp.ClientWebSocketResponse] = None
+        self._session: Optional[aiohttp.ClientSession] = None
         self._conn = None
         self._proxy = proxy
         self._api_key = api_key
@@ -168,13 +168,13 @@ class ReconnectingWebSocket:
             try:
                 res = await asyncio.wait_for(self.ws.receive(), timeout=self.TIMEOUT)
             except asyncio.TimeoutError:
-                logging.debug(f"no message in {self.TIMEOUT} seconds")
+                logging.error(f"no message in {self.TIMEOUT} seconds")
             except asyncio.CancelledError as e:
-                logging.debug(f"cancelled error {e}")
+                logging.error(f"cancelled error {e}")
             except asyncio.IncompleteReadError as e:
-                logging.debug(f"incomplete read error {e}")
+                logging.error(f"incomplete read error {e}")
             except Exception as e:
-                logging.debug(f"exception {e}")
+                logging.error(f"exception {e}")
             else:
                 res = self._handle_message(res)
 
@@ -237,7 +237,7 @@ class ReconnectingWebSocket:
 class OkexSocketManager:
     def __init__(self, proxy=None, api_key: Optional[str] = None, api_secret: Optional[str] = None,
                  api_passphrase: Optional[str] = None):
-        self.ws: ReconnectingWebSocket = None
+        self.ws: Optional[ReconnectingWebSocket] = None
         self._create_ws = partial(
             ReconnectingWebSocket, proxy=proxy, api_key=api_key, api_secret=api_secret, api_passphrase=api_passphrase)
 
